Struct cfn::aws::lambda::FunctionProperties
[−]
[src]
pub struct FunctionProperties {
pub code: Value<Code>,
pub dead_letter_config: Option<Value<DeadLetterConfig>>,
pub description: Option<Value<String>>,
pub environment: Option<Value<Environment>>,
pub function_name: Option<Value<String>>,
pub handler: Value<String>,
pub kms_key_arn: Option<Value<String>>,
pub memory_size: Option<Value<u32>>,
pub reserved_concurrent_executions: Option<Value<u32>>,
pub role: Value<String>,
pub runtime: Value<String>,
pub tags: Option<ValueList<Tag>>,
pub timeout: Option<Value<u32>>,
pub tracing_config: Option<Value<TracingConfig>>,
pub vpc_config: Option<Value<VpcConfig>>,
}Properties for the Function resource.
Fields
code: Value<Code>
Property Code.
Update type: Mutable. AWS CloudFormation doesn't replace the resource when you change this property.
dead_letter_config: Option<Value<DeadLetterConfig>>
Property DeadLetterConfig.
Update type: Mutable. AWS CloudFormation doesn't replace the resource when you change this property.
description: Option<Value<String>>
Property Description.
Update type: Mutable. AWS CloudFormation doesn't replace the resource when you change this property.
environment: Option<Value<Environment>>
Property Environment.
Update type: Mutable. AWS CloudFormation doesn't replace the resource when you change this property.
function_name: Option<Value<String>>
Property FunctionName.
Update type: Immutable. AWS CloudFormation replaces the resource when you change this property.
handler: Value<String>
Property Handler.
Update type: Mutable. AWS CloudFormation doesn't replace the resource when you change this property.
kms_key_arn: Option<Value<String>>
Property KmsKeyArn.
Update type: Mutable. AWS CloudFormation doesn't replace the resource when you change this property.
memory_size: Option<Value<u32>>
Property MemorySize.
Update type: Mutable. AWS CloudFormation doesn't replace the resource when you change this property.
reserved_concurrent_executions: Option<Value<u32>>
Property ReservedConcurrentExecutions.
Update type: Mutable. AWS CloudFormation doesn't replace the resource when you change this property.
role: Value<String>
Property Role.
Update type: Mutable. AWS CloudFormation doesn't replace the resource when you change this property.
runtime: Value<String>
Property Runtime.
Update type: Mutable. AWS CloudFormation doesn't replace the resource when you change this property.
Property Tags.
Update type: Mutable. AWS CloudFormation doesn't replace the resource when you change this property.
timeout: Option<Value<u32>>
Property Timeout.
Update type: Mutable. AWS CloudFormation doesn't replace the resource when you change this property.
tracing_config: Option<Value<TracingConfig>>
Property TracingConfig.
Update type: Mutable. AWS CloudFormation doesn't replace the resource when you change this property.
vpc_config: Option<Value<VpcConfig>>
Property VpcConfig.
Update type: Mutable. AWS CloudFormation doesn't replace the resource when you change this property.